@@ -12,6 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+import json
 
 class ARouteServerError(Exception):
 
@@ -106,6 +107,41 @@ class EuroIXSchemaError(EuroIXError):
                             "the one recognized by this version of the "
                             "program, or that it contains errors.")
 
+class IXFMemberListFromClientsMergeFileError(ARouteServerError):
+
+    def __init__(self, msg, **example_args):
+        ARouteServerError.__init__(self)
+        self.msg = msg
+        self.example_args = example_args
+
+    def __str__(self):
+        EXAMPLE = {
+            "ixp_list": [{
+                "ixp_id": self.example_args["ixp_id"],
+                "ixf_id": self.example_args["ixf_id"],
+                "shortname": self.example_args["shortname"]
+            }]
+        }
+
+        if self.example_args["vlan"]:
+            EXAMPLE["ixp_list"][0]["vlan"] = [{
+                "id": self.example_args["vlan"]
+            }]
+
+        return (
+            "An error occurred due to the content of the --merge-file: {}. "
+            "When a file provided via --merge-file contains the 'ixp_list' "
+            "key, the value of that key is used to replace the same "
+            "attribute that otherwise would be generated by ARouteServer. "
+            "Please be sure that the merge-file 'ixp_list' key contains a "
+            "list made by exactly one dictionary, with at least the "
+            "'ixf_id', 'ixp_id' and 'shortname' keys set correctly.\n"
+            "Example:\n\n{}".format(
+                self.msg,
+                json.dumps(EXAMPLE, indent=2)
+            )
+        )
+
 class RPKIValidatorCacheError(ARouteServerError):
     pass
 
